{ Unit: BcStringsContainerEditor
  ===========================================================================

  The contents of this file are subject to the Bluecave Public License V 1.1
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Component Editor for TBcStringsContainer
    Default action is to show Items property TCollectionEditor.

  History:

    2001-10-01: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcStringsContainerEditor;

interface

uses
{$IFDEF DFS_DELPHI_6_UP}
  DesignIntf,
  DesignEditors,
  DesignMenus,
  ToolsApi,
{$ELSE}
  dsgnintf,
{$ENDIF}
  Windows, SysUtils, Menus, Dialogs, BcStringsContainer;

const
  Verbs: array[0..1] of string =
    ('Edit Strings...',
     'Save All Strings to a File...');

  VerbEditItems = 0;
  VerbSaveStrings = 1;

type
  TBcStringsContainerEditor = class(TComponentEditor)
  public
    function GetVerbCount: Integer; override;
    function GetVerb(Index: Integer): string; override;
{$IFDEF DFS_DELPHI_6_UP}
    procedure PrepareItem(Index: Integer; const AItem: IMenuItem); override;
{$ELSE}
    procedure PrepareItem(Index: Integer; const AItem: TMenuItem); override;
{$ENDIF}
    procedure ExecuteVerb(Index: Integer); override;
  end;

procedure Register;

implementation

uses Classes, ColnEdit, Forms, StrEdit; { Collection Property Editor }

resourcestring
  SDDefaultExt = 'txt';
  SDFilter = 'Text files (*.txt)|*.txt|All files (*.*)|*.*';
  SDTitle = 'Save All Strings to a File';

procedure Register;
begin
  RegisterComponentEditor(TBcStringsContainer, TBcStringsContainerEditor);
end;

{ TBcStringsContainerEditor }

procedure TBcStringsContainerEditor.ExecuteVerb(Index: Integer);
var
  SD: TSaveDialog;
begin
  case Index of
    VerbEditItems:
      begin
        { execute component editor of Items property }
        ShowCollectionEditor(Designer, Component,
          (Component as TBcStringsContainer).Items, 'Items');
      end;
    VerbSaveStrings:
      begin
        try
          SD := TSaveDialog.Create(Application);
          SD.FileName := Component.Name;
          SD.DefaultExt := SDDefaultExt;
          SD.Filter := SDFilter;
          SD.FilterIndex := 0;
          SD.Title := SDTitle;
          SD.Options := [ofOverwritePrompt, ofPathMustExist,	ofEnableSizing];
          if SD.Execute then
            (Component as TBcStringsContainer).SaveToFile(SD.FileName);
        finally
          FreeAndNil(SD);
        end;
      end;
  else
    inherited ExecuteVerb(Index);
  end;
end;

function TBcStringsContainerEditor.GetVerb(Index: Integer): string;
begin
  Result := Verbs[Index];
end;

function TBcStringsContainerEditor.GetVerbCount: Integer;
begin
  Result := High(Verbs) + 1;
end;

{$IFDEF DFS_DELPHI_6_UP}
procedure TBcStringsContainerEditor.PrepareItem(Index: Integer;
  const AItem: IMenuItem);
{$ELSE}
procedure TBcStringsContainerEditor.PrepareItem(Index: Integer;
  const AItem: TMenuItem);
{$ENDIF}
begin
  case Index of
{$IFNDEF DFS_DELPHI_6_UP}
    VerbEditItems: AItem.Default := True;
{$ENDIF}
    VerbSaveStrings: AItem.Enabled := (Component as TBcStringsContainer).Items.Count > 0;
  else
    inherited PrepareItem(Index, AItem);
  end;
end;

end.
